Insert image button

Lisää linkki -nappi | TOC

Lisää linkki -nappi avaa alla näkyvän ikkunan.
Kirjoita haluamasi kuvan URL osoite ja lisää kuvalle selite. Selite näytetään vaihtoehtoisena selitteenä sivulla.
Kenttien selitykset:

Kuvan URL | Kuvan URL tai polku.
Kuvan selite | Vaihtoehtoinen selite kuvan sisällöstä.
Ulottuvuudet | Kuvan leveys ja korkeus.
Asettelu | Kuvan asettelu, käytännöllinen kun halutaan tekstin rivittyvän kuvan ympärille.
Reuna | Kuvaa ympäröivän reunan leveys.
Pystyväli | Pystyväli, käytännöllinen kun halutaan tekstin rivittyvän kuvan ympärille.
Vaakaväli | Vaakaväli, useful when wrapping text around images.

Mene: Sisällysluetteloon | Alkuun